import networkx as nx
import nltk
from nltk.tokenize import sent_tokenize
from sklearn.feature_extraction.text import TfidfVectorizer
from sklearn.metrics.pairwise import cosine_similarity

nltk.download('punkt')
nltk.download('stopwords')


def load_stopwords(file_path):
    with open(file_path, 'r', encoding='UTF-8') as file:
        stopwords = [line.strip() for line in file]
    return stopwords


def summarize_text(file_path, num_sentences):
    with open(file_path, 'r', encoding='UTF-8') as file:
        text = file.read()

    # stop_words = list(set(stopwords.words('polish')))
    stopwords_path = 'polish.stopwords.txt'
    stop_words = load_stopwords(stopwords_path)
    sentences = sent_tokenize(text)

    # Obliczenie podobieństwa zdań za pomocą wektorów TF-IDF i cosinusowej miary podobieństwa
    vectorizer = TfidfVectorizer(stop_words=stop_words)
    sentence_vectors = vectorizer.fit_transform(sentences)
    similarity_matrix = cosine_similarity(sentence_vectors)

    # Tworzenie grafu zdań z macierzą podobieństwa
    sentence_graph = nx.from_numpy_array(similarity_matrix)

    # Obliczenie wartości PageRank dla zdań
    sentence_scores = nx.pagerank(sentence_graph)

    # Sortowanie zdań według ich wartości PageRank
    sorted_sentences = sorted(sentence_scores, key=sentence_scores.get, reverse=True)

    # Wybór zdań o najwyższych wartościach PageRank jako podsumowania
    summary_sentences = [sentences[i] for i in sorted_sentences[:num_sentences]]

    summary = ' '.join(summary_sentences)
    return summary, sentence_scores


if __name__ == "__main__":
    file_path = "texts/wojna-polish.txt"  # Replace with your file path
    num_sentences = 2  # Number of sentences in the summary
    summary, scores = summarize_text(file_path, num_sentences)
    print(summary)
